You are viewing a plain text version of this content. The canonical link for it is here.
Posted to sandesha-dev@ws.apache.org by ch...@apache.org on 2006/05/08 10:25:40 UTC

svn commit: r404962 - in /webservices/sandesha/trunk/interop: conf/ src/org/apache/sandesha2/wsrm_2006_02/

Author: chamikara
Date: Mon May  8 01:25:39 2006
New Revision: 404962

URL: http://svn.apache.org/viewcvs?rev=404962&view=rev
Log:
Updated interop files

Modified:
    webservices/sandesha/trunk/interop/conf/sandesha2_interop.properties
    webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_1.java
    webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_2.java
    webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_3.java
    webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_4.java
    webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_2_1.java
    webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_2_2.java
    webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_2_3.java

Modified: webservices/sandesha/trunk/interop/conf/sandesha2_interop.properties
URL: http://svn.apache.org/viewcvs/webservices/sandesha/trunk/interop/conf/sandesha2_interop.properties?rev=404962&r1=404961&r2=404962&view=diff
==============================================================================
--- webservices/sandesha/trunk/interop/conf/sandesha2_interop.properties (original)
+++ webservices/sandesha/trunk/interop/conf/sandesha2_interop.properties Mon May  8 01:25:39 2006
@@ -1,2 +1,2 @@
 to=http://127.0.0.1:8080/axis2/services/RMSampleService
-transportTo=http://127.0.0.1:8080/axis2/services/RMSampleService
\ No newline at end of file
+transportTo=http://127.0.0.1:8070/axis2/services/RMSampleService
\ No newline at end of file

Modified: webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_1.java
URL: http://svn.apache.org/viewcvs/webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_1.java?rev=404962&r1=404961&r2=404962&view=diff
==============================================================================
--- webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_1.java (original)
+++ webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_1.java Mon May  8 01:25:39 2006
@@ -44,7 +44,7 @@
 public class Scenario_1_1 {
 
 	private static final String applicationNamespaceName = "http://tempuri.org/"; 
-	private static final String Ping = "Ping";
+	private static final String ping = "ping";
 	private static final String Text = "Text";
 	
 	private static String toIP = "127.0.0.1";
@@ -104,7 +104,7 @@
 		
 		clientOptions.setSoapVersionURI(SOAP12Constants.SOAP_ENVELOPE_NAMESPACE_URI);   //uncomment this to send messages in SOAP 1.2
 //		clientOptions.setProperty(AddressingConstants.WS_ADDRESSING_VERSION,AddressingConstants.Submission.WSA_NAMESPACE);
-		clientOptions.setProperty(SandeshaClientConstants.RM_SPEC_VERSION,Sandesha2Constants.SPEC_VERSIONS.WSRX);  //uncomment this to send the messages according to the WSRX spec.
+		clientOptions.setProperty(SandeshaClientConstants.RM_SPEC_VERSION,Sandesha2Constants.SPEC_VERSIONS.v1_1);  //uncomment this to send the messages according to the v1_1 spec.
 		
 		clientOptions.setAction("urn:wsrm:Ping");
 		
@@ -138,7 +138,7 @@
 	private static OMElement getPingOMBlock(String text) {
 		OMFactory fac = OMAbstractFactory.getOMFactory();
 		OMNamespace namespace = fac.createOMNamespace(applicationNamespaceName,"ns1");
-		OMElement pingElem = fac.createOMElement(Ping, namespace);
+		OMElement pingElem = fac.createOMElement(ping, namespace);
 		OMElement textElem = fac.createOMElement(Text, namespace);
 		
 		textElem.setText(text);

Modified: webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_2.java
URL: http://svn.apache.org/viewcvs/webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_2.java?rev=404962&r1=404961&r2=404962&view=diff
==============================================================================
--- webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_2.java (original)
+++ webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_2.java Mon May  8 01:25:39 2006
@@ -43,7 +43,7 @@
 public class Scenario_1_2 {
 
 	private static final String applicationNamespaceName = "http://tempuri.org/"; 
-	private static final String Ping = "Ping";
+	private static final String ping = "ping";
 	private static final String Text = "Text";
 	
 	private static String toIP = "127.0.0.1";
@@ -105,7 +105,7 @@
 
 //		clientOptions.setSoapVersionURI(SOAP12Constants.SOAP_ENVELOPE_NAMESPACE_URI);   //uncomment this to send messages in SOAP 1.2
 		
-		clientOptions.setProperty(SandeshaClientConstants.RM_SPEC_VERSION,Sandesha2Constants.SPEC_VERSIONS.WSRX);  //uncomment this to send the messages according to the WSRX spec.
+		clientOptions.setProperty(SandeshaClientConstants.RM_SPEC_VERSION,Sandesha2Constants.SPEC_VERSIONS.v1_1);  //uncomment this to send the messages according to the v1_1 spec.
 		
 		clientOptions.setAction("urn:wsrm:Ping");
 		
@@ -159,7 +159,7 @@
 	private static OMElement getPingOMBlock(String text) {
 		OMFactory fac = OMAbstractFactory.getOMFactory();
 		OMNamespace namespace = fac.createOMNamespace(applicationNamespaceName,"ns1");
-		OMElement pingElem = fac.createOMElement(Ping, namespace);
+		OMElement pingElem = fac.createOMElement(ping, namespace);
 		OMElement textElem = fac.createOMElement(Text, namespace);
 		
 		textElem.setText(text);

Modified: webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_3.java
URL: http://svn.apache.org/viewcvs/webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_3.java?rev=404962&r1=404961&r2=404962&view=diff
==============================================================================
--- webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_3.java (original)
+++ webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_3.java Mon May  8 01:25:39 2006
@@ -43,7 +43,7 @@
 public class Scenario_1_3 {
 
 	private static final String applicationNamespaceName = "http://tempuri.org/"; 
-	private static final String Ping = "Ping";
+	private static final String ping = "ping";
 	private static final String Text = "Text";
 	
 	private static String toIP = "127.0.0.1";
@@ -103,7 +103,7 @@
 		
 //		clientOptions.setSoapVersionURI(SOAP12Constants.SOAP_ENVELOPE_NAMESPACE_URI);   //uncomment this to send messages in SOAP 1.2
 		
-		clientOptions.setProperty(SandeshaClientConstants.RM_SPEC_VERSION,Sandesha2Constants.SPEC_VERSIONS.WSRX);  //uncomment this to send the messages according to the WSRX spec.
+		clientOptions.setProperty(SandeshaClientConstants.RM_SPEC_VERSION,Sandesha2Constants.SPEC_VERSIONS.v1_1);  //uncomment this to send the messages according to the v1_1 spec.
 		
 //		clientOptions.setProperty(AddressingConstants.WS_ADDRESSING_VERSION,AddressingConstants.Submission.WSA_NAMESPACE);
 
@@ -135,17 +135,17 @@
 
 		SandeshaClient.closeSequence(serviceClient);
 		
-//		clientOptions.setProperty(SandeshaClient.MESSAGE_NUMBER,new Long(4));
-//		serviceClient.fireAndForget(getPingOMBlock("ping4"));	
+		clientOptions.setProperty(SandeshaClientConstants.MESSAGE_NUMBER,new Long(4));
+		serviceClient.fireAndForget(getPingOMBlock("ping4"));	
 
-//		SandeshaClient.terminateSequence(serviceClient);		
+		SandeshaClient.terminateSequence(serviceClient);		
 		serviceClient.finalizeInvoke();
 	}
 	
 	private static OMElement getPingOMBlock(String text) {
 		OMFactory fac = OMAbstractFactory.getOMFactory();
 		OMNamespace namespace = fac.createOMNamespace(applicationNamespaceName,"ns1");
-		OMElement pingElem = fac.createOMElement(Ping, namespace);
+		OMElement pingElem = fac.createOMElement(ping, namespace);
 		OMElement textElem = fac.createOMElement(Text, namespace);
 		
 		textElem.setText(text);

Modified: webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_4.java
URL: http://svn.apache.org/viewcvs/webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_4.java?rev=404962&r1=404961&r2=404962&view=diff
==============================================================================
--- webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_2_1.java (original)
+++ webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_2_1.java Mon May  8 01:25:39 2006
@@ -139,7 +139,7 @@
 		
 //		clientOptions.setSoapVersionURI(SOAP12Constants.SOAP_ENVELOPE_NAMESPACE_URI);   //uncomment this to send messages in SOAP 1.2
 		
-		clientOptions.setProperty(SandeshaClientConstants.RM_SPEC_VERSION,Sandesha2Constants.SPEC_VERSIONS.WSRX);  //uncomment this to send the messages according to the WSRX spec.
+		clientOptions.setProperty(SandeshaClientConstants.RM_SPEC_VERSION,Sandesha2Constants.SPEC_VERSIONS.v1_1);  //uncomment this to send the messages according to the v1_1 spec.
 		
 //		clientOptions.setProperty(AddressingConstants.WS_ADDRESSING_VERSION,AddressingConstants.Submission.WSA_NAMESPACE);
 
@@ -168,7 +168,7 @@
     	SequenceReport sequenceReport = null;		
 		boolean complete = false;
 		while (!complete) {
-//			sequenceReport = SandeshaClient.getOutgoingSequenceReport(serviceClient);
+			sequenceReport = SandeshaClient.getOutgoingSequenceReport(serviceClient);
 			if (sequenceReport!=null && sequenceReport.getCompletedMessages().size()==3) 
 				complete = true;
 			else {

Modified: webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_2_2.java
URL: http://svn.apache.org/viewcvs/webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_2_2.java?rev=404962&r1=404961&r2=404962&view=diff
==============================================================================
--- webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_2_2.java (original)
+++ webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_2_2.java Mon May  8 01:25:39 2006
@@ -120,7 +120,7 @@
 		
 //		clientOptions.setSoapVersionURI(SOAP12Constants.SOAP_ENVELOPE_NAMESPACE_URI);   //uncomment this to send messages in SOAP 1.2
 		
-		clientOptions.setProperty(SandeshaClientConstants.RM_SPEC_VERSION,Sandesha2Constants.SPEC_VERSIONS.WSRX);  //uncomment this to send the messages according to the WSRX spec.
+		clientOptions.setProperty(SandeshaClientConstants.RM_SPEC_VERSION,Sandesha2Constants.SPEC_VERSIONS.v1_1);  //uncomment this to send the messages according to the v1_1 spec.
 		
 //		clientOptions.setProperty(SandeshaClient.OFFERED_SEQUENCE_ID,SandeshaUtil.getUUID());  //Uncomment this to offer a sequenceID for the incoming sequence.
 		

Modified: webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_2_3.java
URL: http://svn.apache.org/viewcvs/webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_2_3.java?rev=404962&r1=404961&r2=404962&view=diff
==============================================================================
--- webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_2_3.java (original)
+++ webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_2_3.java Mon May  8 01:25:39 2006
@@ -139,7 +139,7 @@
 		
 //		clientOptions.setProperty(AddressingConstants.WS_ADDRESSING_VERSION,AddressingConstants.Submission.WSA_NAMESPACE);
 
-		clientOptions.setProperty(SandeshaClientConstants.RM_SPEC_VERSION,Sandesha2Constants.SPEC_VERSIONS.WSRX);  //uncomment this to send the messages according to the WSRX spec.
+		clientOptions.setProperty(SandeshaClientConstants.RM_SPEC_VERSION,Sandesha2Constants.SPEC_VERSIONS.v1_1);  //uncomment this to send the messages according to the v1_1 spec.
 		
 		clientOptions.setProperty(SandeshaClientConstants.OFFERED_SEQUENCE_ID,SandeshaUtil.getUUID());  //single characted offers are declined by the server
 		



---------------------------------------------------------------------
To unsubscribe, e-mail: sandesha-dev-unsubscribe@ws.apache.org
For additional commands, e-mail: sandesha-dev-help@ws.apache.org
--- webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_4.java (original)
+++ webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_1_4.java Mon May  8 01:25:39 2006
@@ -45,7 +45,7 @@
 
 	private static final String applicationNamespaceName = "http://tempuri.org/";
 
-	private static final String Ping = "Ping";
+	private static final String ping = "ping";
 
 	private static final String Text = "Text";
 
@@ -132,9 +132,9 @@
 		// //uncomment this to send messages in SOAP 1.2
 
 		clientOptions.setProperty(SandeshaClientConstants.RM_SPEC_VERSION,
-				Sandesha2Constants.SPEC_VERSIONS.WSRX); // uncomment this to
+				Sandesha2Constants.SPEC_VERSIONS.v1_1); // uncomment this to
 														// send the messages
 														// according to the WSRX
 														// spec.
 
 		serviceClient.setOptions(clientOptions);
@@ -165,7 +165,7 @@
 		OMFactory fac = OMAbstractFactory.getOMFactory();
 		OMNamespace namespace = fac.createOMNamespace(applicationNamespaceName,
 				"ns1");
-		OMElement pingElem = fac.createOMElement(Ping, namespace);
+		OMElement pingElem = fac.createOMElement(ping, namespace);
 		OMElement textElem = fac.createOMElement(Text, namespace);
 
 		textElem.setText(text);
@@ -132,9 +132,9 @@
 														// send the messages
-														// according to the WSRX
+														// according to the v1_1
 														// spec.
 

Modified: webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_2_1.java
URL: http://svn.apache.org/viewcvs/webservices/sandesha/trunk/interop/src/org/apache/sandesha2/wsrm_2006_02/Scenario_2_1.java?rev=404962&r1=404961&r2=404962&view=diff
==============================================================================